<?php
/*---------------------------------------------------------------
		verifStart.php
-----------------------------------------------------------------
	Vérifie si on doit démarrer ou non les stations d'après le calendrier
-----------------------------------------------------------------
	auteur : Olivier HACQUARD - Académie de Besançon   
---------------------------------------------------------------*/
//on récupère le dossier d'origine
$chemin_ori=getcwd();

//on change de dossier pour le dossier courant de l'appli
$chemin_appli=substr($_SERVER['PHP_SELF'],0,strrpos($_SERVER['PHP_SELF'],'/'));
chdir($chemin_appli);

include ('./inc/f_mysql.inc.php');

$result='0';
$query='SELECT num_legende FROM cal_endrier WHERE la_date="'.date("Y-m-d", time()).'"';
//echo $query."\n";
$res=$mysqli->query($query);
if (list($_num)=$res->fetch_array()) $result=$_num;
echo trim($result);

//retour dans le dossier d'origine
chdir($chemin_ori);

?>